<?php

namespace Drupal\hubspot_forms\Plugin\Block;

use Drupal\Component\Utility\Html;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\hubspot_forms\HubspotForms;

/**
 * Display Hubspot Forms block.
 *
 * @Block(
 *   id = "hubspot_forms",
 *   admin_label = @Translation("Hubspot Forms")
 * )
 */
class HubspotBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * @var $account \Drupal\hubspot_forms\HubspotForms
   */
  protected $hubspotForms;

  /**
   * The language manager service.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * @param array $configuration
   * @param string $plugin_id
   * @param mixed $plugin_definition
   * @param \Drupal\hubspot_forms\HubspotForms $hubspot_forms
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, HubspotForms $hubspot_forms, LanguageManagerInterface $language_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->hubspotForms = $hubspot_forms;
    $this->languageManager = $language_manager;
  }

  /**
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   * @param array $configuration
   * @param string $plugin_id
   * @param mixed $plugin_definition
   *
   * @return static
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('hubspot_forms'),
      $container->get('language_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return ['form_id' => ''];
  }

  /**
   * {@inheritdoc}
   * @throws \GuzzleHttp\Exception\GuzzleException
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form['form_id'] = [
      '#type' => 'select',
      '#title' => $this->t('Hubspot Form'),
      '#description' => $this->t('Please choose a form you would like to display.'),
      '#options' => $this->hubspotForms->getFormIds(),
      '#default_value' => $this->configuration['form_id'],
      '#required' => TRUE,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['form_id'] = $form_state->getValue('form_id');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    [$portal_id, $form_id] = explode('::', $this->configuration['form_id']);
    return [
      '#theme' => 'hubspot_form',
      '#target' => Html::getUniqueId('block-' . $this->getBaseId() . '-' . $form_id),
      '#portal_id' => $portal_id,
      '#form_id' => $form_id,
      '#locale' => $this->languageManager->getCurrentLanguage()->getId(),
    ];
  }

}
