<?php

namespace Drupal\hubspot_forms\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\hubspot_forms\HubspotForms;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'field_hubspot_form_formatter_label' formatter.
 *
 * @FieldFormatter(
 *   id = "field_hubspot_form_formatter_label",
 *   module = "hubspot_forms",
 *   label = @Translation("Display Hubspot form label"),
 *   field_types = {
 *     "field_hubspot_form"
 *   }
 * )
 */
class HubspotFormFormatterLabel extends FormatterBase implements ContainerFactoryPluginInterface {

  /**
   * @var $account \Drupal\hubspot_forms\HubspotForms
   */
  protected $hubspotForms;

  /**
   * Constructs a FormatterBase object.
   *
   * @param string $plugin_id
   *   The plugin_id for the formatter.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The definition of the field to which the formatter is associated.
   * @param array $settings
   *   The formatter settings.
   * @param string $label
   *   The formatter label display setting.
   * @param string $view_mode
   *   The view mode.
   * @param array $third_party_settings
   *   Any third party settings.
   * @param HubspotForms $hubspot_forms
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, $label, $view_mode, array $third_party_settings, HubspotForms $hubspot_forms) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);
    $this->hubspotForms = $hubspot_forms;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('hubspot_forms')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $forms = $this->hubspotForms->getFormIds();
    foreach ($items as $delta => $item) {
      $form_id = $item->get('form_id')->getValue();
      if ($this->hubspotForms->isConnected()) {
        $elements[$delta] = [
          '#type' => 'markup',
          '#markup' => $forms[$form_id],
        ];
      }
      else {
        $elements[$delta] = [
          '#markup' => $this->t('Please provide a valid Hubspot API key.'),
        ];
      }
    }
    return $elements;
  }

}
