<?php

namespace Drupal\hubspot_forms\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\hubspot_forms\HubspotForms;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'field_hubspot_select' widget.
 *
 * @FieldWidget(
 *   id = "field_hubspot_select",
 *   module = "hubspot_forms",
 *   label = @Translation("Hubspot Form"),
 *   field_types = {
 *     "field_hubspot_form"
 *   }
 * )
 */
class HubspotFormSelectWidget extends WidgetBase implements ContainerFactoryPluginInterface {

  /**
   * @var $account \Drupal\hubspot_forms\HubspotForms
   */
  protected $hubspotForms;

  /**
   * Constructs a HubspotFormSelectWidget object.
   *
   * @param string $plugin_id
   *   The plugin_id for the widget.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The definition of the field to which the widget is associated.
   * @param array $settings
   *   The widget settings.
   * @param array $third_party_settings
   *   Any third party settings.
   * @param HubspotForms $hubspot_forms
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, array $third_party_settings, HubspotForms $hubspot_forms) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $third_party_settings);
    $this->hubspotForms = $hubspot_forms;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['third_party_settings'],
      $container->get('hubspot_forms')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element += [
      '#type' => 'select',
      '#title' => $this->t('Hubspot Form'),
      '#options' => $this->hubspotForms->getFormIds(),
      '#default_value' => $items[$delta]->form_id ?? '',
      '#required' => TRUE,
    ];
    return [
      'form_id' => $element,
    ];
  }

}
